Metadata-Version: 2.1
Name: adsbcot
Version: 3.0.0b7
Summary: ADS-B Cursor-on-Target Gateway.
Home-page: https://github.com/ampledata/adsbcot
Author: Greg Albrecht
Author-email: oss@undef.net
License: Copyright 2020 Orion Labs, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Description: adsbcot - ADSB Cursor-on-Target Gateway.
        ****************************************
        
        .. image:: https://raw.githubusercontent.com/ampledata/adsbcot/main/docs/screenshot-1604561447-25.png
           :alt: Screenshot of ADS-B PLI in ATAK.
           :target: https://github.com/ampledata/adsbcot/blob/main/docs/screenshot-1604561447.png
        
        The adsbcot ADS-B Cursor on Target Gateway transforms Automatic Dependent
        Surveillance-Broadcast (ADS-B) aircraft position information into Cursor on
        Target (CoT) Position Location Information (PLI) for display on Situational
        Awareness (SA) applications such as the Android Team Awareness Kit (ATAK),
        WinTAK, RaptorX, et al.
        
        **IF YOU HAVE AN URGENT OPERATIONAL NEED**: Email ops@undef.net or call/sms +1-415-598-8226
        
        ADS-B Data can be recevied from a dump1090 recevier using:
        1. Aircraft JSON HTTP feed. See: https://github.com/flightaware/dump1090/blob/master/README-json.md
        2. Raw TCP (via `pyModeS <https://github.com/junzis/pyModeS>`_)
        3. Beast TCP (via `pyModeS <https://github.com/junzis/pyModeS>`_)
        
        If you'd like to feed AIS data from another source, consider these:
        
        * `adsbxcot <https://github.com/ampledata/adsbxcot>`_: ADS-B Exchange to Cursor on Target (CoT) Gateway. Transforms ADS-B position messages to CoT PLI Events.
        * `stratuxcot <https://github.com/ampledata/stratuxcot>`_: Stratux ADS-B to Cursor on Target (CoT) Gateway. Transforms position messages to CoT PLI Events.
        
        Installation
        ============
        
        The ADS-B to Cursor on Target Gateway is provided by a command-line tool called
        `adsbcot`, which can be installed either from the Python Package Index, or
        directly from this source tree.
        
        Install from the Python Package Index (PyPI)::
        
            $ pip install adsbcot
        
        
        To support direct network streaming (raw & beast) from dump1090, you must
        install the extra package `pyModeS <https://github.com/junzis/pyModeS>`_.
        
        To install with pyModeS support::
        
            $ pip install adsbcot[with_pymodes]
        
        
        Install from this source tree::
        
            $ git clone https://github.com/ampledata/adsbcot.git
            $ cd adsbcot/
            $ python setup.py install
        
        
        Usage
        =====
        
        The `adsbcot` command-line program has several runtime arguments::
        
             usage: adsbcot [-h] -C COT_HOST [-P COT_PORT] [-S STALE] [-I INTERVAL]
                           [-U URL] [-X ADSBX_API_KEY]
        
              optional arguments:
                -h, --help            show this help message and exit
                -C COT_HOST, --cot_host COT_HOST
                                      CoT Destination Host (or Host:Port)
                -P COT_PORT, --cot_port COT_PORT
                                      CoT Destination Port
                -S STALE, --stale STALE
                                      CoT Stale period, in seconds
                -I INTERVAL, --interval INTERVAL
                                      For HTTP: Polling Interval
                -U URL, --url URL     ADS-B Source URL.
                -X ADSBX_API_KEY, --adsbx_api_key ADSBX_API_KEY
                                      ADS-B Exchange API Key
        
        
        Troubleshooting
        ===============
        
        To report bugs, please set the DEBUG=1 environment variable to collect logs.
        
        Unit Test/Build Status
        ======================
        
        adsbcot's current unit test and build status is available via Travis CI:
        
        .. image:: https://travis-ci.com/ampledata/adsbcot.svg?branch=master
            :target: https://travis-ci.com/ampledata/adsbcot
        
        Source
        ======
        The source for adsbcot can be found on Github: https://github.com/ampledata/adsbcot
        
        Author
        ======
        adsbcot is written and maintained by Greg Albrecht W2GMD oss@undef.net
        
        https://ampledata.org/
        
        Copyright
        =========
        adsbcot is Copyright 2020 Orion Labs, Inc. https://www.orionlabs.io
        
        `pyModeS <https://github.com/junzis/pyModeS>`_ is an optional extra package,
        and is Copyright (C) 2015 Junzi Sun (TU Delft).
        
        License
        =======
        adsbcot is licensed under the Apache License, Version 2.0. See LICENSE for details.
        
        `pyModeS <https://github.com/junzis/pyModeS>`_ is an optional extra package,
        and is licensed under the GNU General Public License v3.0.
        
        Examples
        ========
        Connect to dump1090's Beast TCP running on host 172.17.2.122, port 30005 &
        forward CoT to host 172.17.2.152, port 8087::
        
            $ adsbcot -C 172.17.2.152:8087 -U tcp+beast:172.17.2.122:30005
        
        
        Connect to dump1090's Raw TCP running on host 172.17.2.122, port 30003 &
        forward CoT to host 172.17.2.152, port 8087::
        
            $ adsbcot -C 172.17.2.152:8087 -U tcp+raw:172.17.2.122:30003
        
        
        Poll dump1090's JSON API at http://172.17.2.122:8080/data/aircraft.json with a
        10 second interval & forward CoT to host 172.17.2.152, port 8087::
        
            $ adsbcot -C 172.17.2.152:8087 -U http://172.17.2.122:8080/data/aircraft.json -I 10
        
        Poll ADS-B Exchange's API every 5 seconds & forward CoT to host 127.0.0.1, port
        8087::
        
            $ adsbcot -U https://adsbexchange.com/api/aircraft/v2/lat/36.7783/lon/-119.4179/dist/400/ -X SECRET_API_KEY -I 5 -C 127.0.0.1 -P 8087
        
        
        Running as a Daemon
        ===================
        First, install supervisor::
        
            $ sudo yum install supervisor
            $ sudo service supervisord start
        
        Create /etc/supervisor.d/adsbcot.ini with the following content::
        
            [program:adsbcot]
            command=adsbcot -U https://adsbexchange.com/api/aircraft/v2/lat/36.7783/lon/-119.4179/dist/400/ -X xxx -I 5 -C 127.0.0.1 -P 8087
        
        And update supervisor::
        
            $ sudo supervisorctl update
        
Keywords: ADS-B,ADSB,Cursor on Target,ATAK,TAK,CoT
Platform: UNKNOWN
Classifier: Topic :: Communications :: Ham Radio
Classifier: Programming Language :: Python
Classifier: License :: OSI Approved :: Apache Software License
Provides-Extra: with_pymodes
